from typing import NewType

Microseconds = NewType("Microseconds", float)
Milliseconds = NewType("Milliseconds", float)
Seconds = NewType("Seconds", float)
Minutes = NewType("Minutes", float)
Hours = NewType("Hours", float)
Days = NewType("Days", float)
